@@ -7,7 +7,7 @@ X, Y, Z = 0, 1, 2
 
 
 def point_to_section_segment(neuron, point):
-    '''find section and segment that matches the point
+    '''Find section and segment that matches the point.
 
     Only the first point found with the *exact* same coordinates as the point argument is considered
 
@@ -15,7 +15,9 @@ def point_to_section_segment(neuron, point):
         neuron (morphio.Morphology): neuron object
         point (point): value of the point to find in the h5 file
 
-    Returns a tuple (NeuroM section ID, point ID) of the point the matches the input coordinates
+    Returns:
+        Tuple: (NeuroM/MorphIO section ID, point ID) of the point the matches the input coordinates.
+        Since NeuroM v2, section ids of NeuroM and MorphIO are the same excluding soma.
     '''
 
     for section in neuron.iter():
@@ -25,6 +27,6 @@ def point_to_section_segment(neuron, point):
                           (points[:, Z] == point[COLS.Z]))
         if offset[0].size:
             # Section ids start at 0 in MorphIO
-            return (section.id + 1, offset[0][0])
+            return section.id, offset[0][0]
 
     raise ValueError('Cannot find point in morphology that matches: {}'.format(point))
